#

##

##

    	seed

    	objectives ranked

    		( )
    			wert yuio
    			sdfg hjkl

    	possibilities

    		( )
    			sdfg yuio
    			xcvb hjkl

    		( )
    			sdfg hjkl
    			xcvb nm,.

    		( )
    			wert yuio
    			sdfg hjkl

    		( )
    			asdf jkl;
    			zxcv nm,.

    		( )
    			2345
    			wert
    			sdfg
    			xcvb

    		( )
    			1234
    			qwer
    			asdf
    			zxcv